"""
Main interface for greengrassv2 service type definitions.

Usage::

    ```python
    from mypy_boto3_greengrassv2.type_defs import CloudComponentStatusTypeDef

    data: CloudComponentStatusTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import IO, Dict, List, Union

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "CloudComponentStatusTypeDef",
    "ComponentConfigurationUpdateTypeDef",
    "ComponentDependencyRequirementTypeDef",
    "ComponentDeploymentSpecificationTypeDef",
    "ComponentLatestVersionTypeDef",
    "ComponentPlatformTypeDef",
    "ComponentRunWithTypeDef",
    "ComponentTypeDef",
    "ComponentVersionListItemTypeDef",
    "CoreDeviceTypeDef",
    "DeploymentComponentUpdatePolicyTypeDef",
    "DeploymentConfigurationValidationPolicyTypeDef",
    "DeploymentIoTJobConfigurationTypeDef",
    "DeploymentPoliciesTypeDef",
    "DeploymentTypeDef",
    "EffectiveDeploymentTypeDef",
    "InstalledComponentTypeDef",
    "IoTJobAbortConfigTypeDef",
    "IoTJobAbortCriteriaTypeDef",
    "IoTJobExecutionsRolloutConfigTypeDef",
    "IoTJobExponentialRolloutRateTypeDef",
    "IoTJobRateIncreaseCriteriaTypeDef",
    "IoTJobTimeoutConfigTypeDef",
    "LambdaContainerParamsTypeDef",
    "LambdaDeviceMountTypeDef",
    "LambdaEventSourceTypeDef",
    "LambdaExecutionParametersTypeDef",
    "LambdaLinuxProcessParamsTypeDef",
    "LambdaVolumeMountTypeDef",
    "ResolvedComponentVersionTypeDef",
    "CancelDeploymentResponseTypeDef",
    "ComponentCandidateTypeDef",
    "CreateComponentVersionResponseTypeDef",
    "CreateDeploymentResponseTypeDef",
    "DescribeComponentResponseTypeDef",
    "GetComponentResponseTypeDef",
    "GetComponentVersionArtifactResponseTypeDef",
    "GetCoreDeviceResponseTypeDef",
    "GetDeploymentResponseTypeDef",
    "LambdaFunctionRecipeSourceTypeDef",
    "ListComponentVersionsResponseTypeDef",
    "ListComponentsResponseTypeDef",
    "ListCoreDevicesResponseTypeDef",
    "ListDeploymentsResponseTypeDef",
    "ListEffectiveDeploymentsResponseTypeDef",
    "ListInstalledComponentsResponseTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "PaginatorConfigTypeDef",
    "ResolveComponentCandidatesResponseTypeDef",
)

CloudComponentStatusTypeDef = TypedDict(
    "CloudComponentStatusTypeDef",
    {
        "componentState": Literal["REQUESTED", "INITIATED", "DEPLOYABLE", "FAILED", "DEPRECATED"],
        "message": str,
        "errors": Dict[str, str],
    },
    total=False,
)

ComponentConfigurationUpdateTypeDef = TypedDict(
    "ComponentConfigurationUpdateTypeDef", {"merge": str, "reset": List[str]}, total=False
)

ComponentDependencyRequirementTypeDef = TypedDict(
    "ComponentDependencyRequirementTypeDef",
    {"versionRequirement": str, "dependencyType": Literal["HARD", "SOFT"]},
    total=False,
)

ComponentDeploymentSpecificationTypeDef = TypedDict(
    "ComponentDeploymentSpecificationTypeDef",
    {
        "componentVersion": str,
        "configurationUpdate": "ComponentConfigurationUpdateTypeDef",
        "runWith": "ComponentRunWithTypeDef",
    },
    total=False,
)

ComponentLatestVersionTypeDef = TypedDict(
    "ComponentLatestVersionTypeDef",
    {
        "arn": str,
        "componentVersion": str,
        "creationTimestamp": datetime,
        "description": str,
        "publisher": str,
        "platforms": List["ComponentPlatformTypeDef"],
    },
    total=False,
)

ComponentPlatformTypeDef = TypedDict(
    "ComponentPlatformTypeDef", {"name": str, "attributes": Dict[str, str]}, total=False
)

ComponentRunWithTypeDef = TypedDict("ComponentRunWithTypeDef", {"posixUser": str}, total=False)

ComponentTypeDef = TypedDict(
    "ComponentTypeDef",
    {"arn": str, "componentName": str, "latestVersion": "ComponentLatestVersionTypeDef"},
    total=False,
)

ComponentVersionListItemTypeDef = TypedDict(
    "ComponentVersionListItemTypeDef",
    {"componentName": str, "componentVersion": str, "arn": str},
    total=False,
)

CoreDeviceTypeDef = TypedDict(
    "CoreDeviceTypeDef",
    {
        "coreDeviceThingName": str,
        "status": Literal["HEALTHY", "UNHEALTHY"],
        "lastStatusUpdateTimestamp": datetime,
    },
    total=False,
)

DeploymentComponentUpdatePolicyTypeDef = TypedDict(
    "DeploymentComponentUpdatePolicyTypeDef",
    {"timeoutInSeconds": int, "action": Literal["NOTIFY_COMPONENTS", "SKIP_NOTIFY_COMPONENTS"]},
    total=False,
)

DeploymentConfigurationValidationPolicyTypeDef = TypedDict(
    "DeploymentConfigurationValidationPolicyTypeDef", {"timeoutInSeconds": int}, total=False
)

DeploymentIoTJobConfigurationTypeDef = TypedDict(
    "DeploymentIoTJobConfigurationTypeDef",
    {
        "jobExecutionsRolloutConfig": "IoTJobExecutionsRolloutConfigTypeDef",
        "abortConfig": "IoTJobAbortConfigTypeDef",
        "timeoutConfig": "IoTJobTimeoutConfigTypeDef",
    },
    total=False,
)

DeploymentPoliciesTypeDef = TypedDict(
    "DeploymentPoliciesTypeDef",
    {
        "failureHandlingPolicy": Literal["ROLLBACK", "DO_NOTHING"],
        "componentUpdatePolicy": "DeploymentComponentUpdatePolicyTypeDef",
        "configurationValidationPolicy": "DeploymentConfigurationValidationPolicyTypeDef",
    },
    total=False,
)

DeploymentTypeDef = TypedDict(
    "DeploymentTypeDef",
    {
        "targetArn": str,
        "revisionId": str,
        "deploymentId": str,
        "deploymentName": str,
        "creationTimestamp": datetime,
        "deploymentStatus": Literal["ACTIVE", "COMPLETED", "CANCELED", "FAILED", "INACTIVE"],
        "isLatestForTarget": bool,
    },
    total=False,
)

_RequiredEffectiveDeploymentTypeDef = TypedDict(
    "_RequiredEffectiveDeploymentTypeDef",
    {
        "deploymentId": str,
        "deploymentName": str,
        "targetArn": str,
        "coreDeviceExecutionStatus": Literal[
            "IN_PROGRESS", "QUEUED", "FAILED", "COMPLETED", "TIMED_OUT", "CANCELED", "REJECTED"
        ],
        "creationTimestamp": datetime,
        "modifiedTimestamp": datetime,
    },
)
_OptionalEffectiveDeploymentTypeDef = TypedDict(
    "_OptionalEffectiveDeploymentTypeDef",
    {"iotJobId": str, "iotJobArn": str, "description": str, "reason": str},
    total=False,
)

class EffectiveDeploymentTypeDef(
    _RequiredEffectiveDeploymentTypeDef, _OptionalEffectiveDeploymentTypeDef
):
    pass

InstalledComponentTypeDef = TypedDict(
    "InstalledComponentTypeDef",
    {
        "componentName": str,
        "componentVersion": str,
        "lifecycleState": Literal[
            "NEW", "INSTALLED", "STARTING", "RUNNING", "STOPPING", "ERRORED", "BROKEN", "FINISHED"
        ],
        "lifecycleStateDetails": str,
        "isRoot": bool,
    },
    total=False,
)

IoTJobAbortConfigTypeDef = TypedDict(
    "IoTJobAbortConfigTypeDef", {"criteriaList": List["IoTJobAbortCriteriaTypeDef"]}
)

IoTJobAbortCriteriaTypeDef = TypedDict(
    "IoTJobAbortCriteriaTypeDef",
    {
        "failureType": Literal["FAILED", "REJECTED", "TIMED_OUT", "ALL"],
        "action": Literal["CANCEL"],
        "thresholdPercentage": float,
        "minNumberOfExecutedThings": int,
    },
)

IoTJobExecutionsRolloutConfigTypeDef = TypedDict(
    "IoTJobExecutionsRolloutConfigTypeDef",
    {"exponentialRate": "IoTJobExponentialRolloutRateTypeDef", "maximumPerMinute": int},
    total=False,
)

IoTJobExponentialRolloutRateTypeDef = TypedDict(
    "IoTJobExponentialRolloutRateTypeDef",
    {
        "baseRatePerMinute": int,
        "incrementFactor": float,
        "rateIncreaseCriteria": "IoTJobRateIncreaseCriteriaTypeDef",
    },
)

IoTJobRateIncreaseCriteriaTypeDef = TypedDict(
    "IoTJobRateIncreaseCriteriaTypeDef",
    {"numberOfNotifiedThings": int, "numberOfSucceededThings": int},
    total=False,
)

IoTJobTimeoutConfigTypeDef = TypedDict(
    "IoTJobTimeoutConfigTypeDef", {"inProgressTimeoutInMinutes": int}, total=False
)

LambdaContainerParamsTypeDef = TypedDict(
    "LambdaContainerParamsTypeDef",
    {
        "memorySizeInKB": int,
        "mountROSysfs": bool,
        "volumes": List["LambdaVolumeMountTypeDef"],
        "devices": List["LambdaDeviceMountTypeDef"],
    },
    total=False,
)

_RequiredLambdaDeviceMountTypeDef = TypedDict("_RequiredLambdaDeviceMountTypeDef", {"path": str})
_OptionalLambdaDeviceMountTypeDef = TypedDict(
    "_OptionalLambdaDeviceMountTypeDef",
    {"permission": Literal["ro", "rw"], "addGroupOwner": bool},
    total=False,
)

class LambdaDeviceMountTypeDef(
    _RequiredLambdaDeviceMountTypeDef, _OptionalLambdaDeviceMountTypeDef
):
    pass

LambdaEventSourceTypeDef = TypedDict(
    "LambdaEventSourceTypeDef", {"topic": str, "type": Literal["PUB_SUB", "IOT_CORE"]}
)

LambdaExecutionParametersTypeDef = TypedDict(
    "LambdaExecutionParametersTypeDef",
    {
        "eventSources": List["LambdaEventSourceTypeDef"],
        "maxQueueSize": int,
        "maxInstancesCount": int,
        "maxIdleTimeInSeconds": int,
        "timeoutInSeconds": int,
        "statusTimeoutInSeconds": int,
        "pinned": bool,
        "inputPayloadEncodingType": Literal["json", "binary"],
        "execArgs": List[str],
        "environmentVariables": Dict[str, str],
        "linuxProcessParams": "LambdaLinuxProcessParamsTypeDef",
    },
    total=False,
)

LambdaLinuxProcessParamsTypeDef = TypedDict(
    "LambdaLinuxProcessParamsTypeDef",
    {
        "isolationMode": Literal["GreengrassContainer", "NoContainer"],
        "containerParams": "LambdaContainerParamsTypeDef",
    },
    total=False,
)

_RequiredLambdaVolumeMountTypeDef = TypedDict(
    "_RequiredLambdaVolumeMountTypeDef", {"sourcePath": str, "destinationPath": str}
)
_OptionalLambdaVolumeMountTypeDef = TypedDict(
    "_OptionalLambdaVolumeMountTypeDef",
    {"permission": Literal["ro", "rw"], "addGroupOwner": bool},
    total=False,
)

class LambdaVolumeMountTypeDef(
    _RequiredLambdaVolumeMountTypeDef, _OptionalLambdaVolumeMountTypeDef
):
    pass

ResolvedComponentVersionTypeDef = TypedDict(
    "ResolvedComponentVersionTypeDef",
    {"arn": str, "componentName": str, "componentVersion": str, "recipe": Union[bytes, IO[bytes]]},
    total=False,
)

CancelDeploymentResponseTypeDef = TypedDict(
    "CancelDeploymentResponseTypeDef", {"message": str}, total=False
)

ComponentCandidateTypeDef = TypedDict(
    "ComponentCandidateTypeDef",
    {"componentName": str, "componentVersion": str, "versionRequirements": Dict[str, str]},
    total=False,
)

_RequiredCreateComponentVersionResponseTypeDef = TypedDict(
    "_RequiredCreateComponentVersionResponseTypeDef",
    {
        "componentName": str,
        "componentVersion": str,
        "creationTimestamp": datetime,
        "status": "CloudComponentStatusTypeDef",
    },
)
_OptionalCreateComponentVersionResponseTypeDef = TypedDict(
    "_OptionalCreateComponentVersionResponseTypeDef", {"arn": str}, total=False
)

class CreateComponentVersionResponseTypeDef(
    _RequiredCreateComponentVersionResponseTypeDef, _OptionalCreateComponentVersionResponseTypeDef
):
    pass

CreateDeploymentResponseTypeDef = TypedDict(
    "CreateDeploymentResponseTypeDef",
    {"deploymentId": str, "iotJobId": str, "iotJobArn": str},
    total=False,
)

DescribeComponentResponseTypeDef = TypedDict(
    "DescribeComponentResponseTypeDef",
    {
        "arn": str,
        "componentName": str,
        "componentVersion": str,
        "creationTimestamp": datetime,
        "publisher": str,
        "description": str,
        "status": "CloudComponentStatusTypeDef",
        "platforms": List["ComponentPlatformTypeDef"],
        "tags": Dict[str, str],
    },
    total=False,
)

_RequiredGetComponentResponseTypeDef = TypedDict(
    "_RequiredGetComponentResponseTypeDef",
    {"recipeOutputFormat": Literal["JSON", "YAML"], "recipe": Union[bytes, IO[bytes]]},
)
_OptionalGetComponentResponseTypeDef = TypedDict(
    "_OptionalGetComponentResponseTypeDef", {"tags": Dict[str, str]}, total=False
)

class GetComponentResponseTypeDef(
    _RequiredGetComponentResponseTypeDef, _OptionalGetComponentResponseTypeDef
):
    pass

GetComponentVersionArtifactResponseTypeDef = TypedDict(
    "GetComponentVersionArtifactResponseTypeDef", {"preSignedUrl": str}
)

GetCoreDeviceResponseTypeDef = TypedDict(
    "GetCoreDeviceResponseTypeDef",
    {
        "coreDeviceThingName": str,
        "coreVersion": str,
        "platform": str,
        "architecture": str,
        "status": Literal["HEALTHY", "UNHEALTHY"],
        "lastStatusUpdateTimestamp": datetime,
        "tags": Dict[str, str],
    },
    total=False,
)

GetDeploymentResponseTypeDef = TypedDict(
    "GetDeploymentResponseTypeDef",
    {
        "targetArn": str,
        "revisionId": str,
        "deploymentId": str,
        "deploymentName": str,
        "deploymentStatus": Literal["ACTIVE", "COMPLETED", "CANCELED", "FAILED", "INACTIVE"],
        "iotJobId": str,
        "iotJobArn": str,
        "components": Dict[str, "ComponentDeploymentSpecificationTypeDef"],
        "deploymentPolicies": "DeploymentPoliciesTypeDef",
        "iotJobConfiguration": "DeploymentIoTJobConfigurationTypeDef",
        "creationTimestamp": datetime,
        "isLatestForTarget": bool,
        "tags": Dict[str, str],
    },
    total=False,
)

_RequiredLambdaFunctionRecipeSourceTypeDef = TypedDict(
    "_RequiredLambdaFunctionRecipeSourceTypeDef", {"lambdaArn": str}
)
_OptionalLambdaFunctionRecipeSourceTypeDef = TypedDict(
    "_OptionalLambdaFunctionRecipeSourceTypeDef",
    {
        "componentName": str,
        "componentVersion": str,
        "componentPlatforms": List["ComponentPlatformTypeDef"],
        "componentDependencies": Dict[str, "ComponentDependencyRequirementTypeDef"],
        "componentLambdaParameters": "LambdaExecutionParametersTypeDef",
    },
    total=False,
)

class LambdaFunctionRecipeSourceTypeDef(
    _RequiredLambdaFunctionRecipeSourceTypeDef, _OptionalLambdaFunctionRecipeSourceTypeDef
):
    pass

ListComponentVersionsResponseTypeDef = TypedDict(
    "ListComponentVersionsResponseTypeDef",
    {"componentVersions": List["ComponentVersionListItemTypeDef"], "nextToken": str},
    total=False,
)

ListComponentsResponseTypeDef = TypedDict(
    "ListComponentsResponseTypeDef",
    {"components": List["ComponentTypeDef"], "nextToken": str},
    total=False,
)

ListCoreDevicesResponseTypeDef = TypedDict(
    "ListCoreDevicesResponseTypeDef",
    {"coreDevices": List["CoreDeviceTypeDef"], "nextToken": str},
    total=False,
)

ListDeploymentsResponseTypeDef = TypedDict(
    "ListDeploymentsResponseTypeDef",
    {"deployments": List["DeploymentTypeDef"], "nextToken": str},
    total=False,
)

ListEffectiveDeploymentsResponseTypeDef = TypedDict(
    "ListEffectiveDeploymentsResponseTypeDef",
    {"effectiveDeployments": List["EffectiveDeploymentTypeDef"], "nextToken": str},
    total=False,
)

ListInstalledComponentsResponseTypeDef = TypedDict(
    "ListInstalledComponentsResponseTypeDef",
    {"installedComponents": List["InstalledComponentTypeDef"], "nextToken": str},
    total=False,
)

ListTagsForResourceResponseTypeDef = TypedDict(
    "ListTagsForResourceResponseTypeDef", {"tags": Dict[str, str]}, total=False
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
)

ResolveComponentCandidatesResponseTypeDef = TypedDict(
    "ResolveComponentCandidatesResponseTypeDef",
    {"resolvedComponentVersions": List["ResolvedComponentVersionTypeDef"]},
    total=False,
)



"""
Main interface for greengrassv2 service client paginators.

Usage::

    ```python
    import boto3

    from mypy_boto3_greengrassv2 import GreengrassV2Client
    from mypy_boto3_greengrassv2.paginator import (
        ListComponentVersionsPaginator,
        ListComponentsPaginator,
        ListCoreDevicesPaginator,
        ListDeploymentsPaginator,
        ListEffectiveDeploymentsPaginator,
        ListInstalledComponentsPaginator,
    )

    client: GreengrassV2Client = boto3.client("greengrassv2")

    list_component_versions_paginator: ListComponentVersionsPaginator = client.get_paginator("list_component_versions")
    list_components_paginator: ListComponentsPaginator = client.get_paginator("list_components")
    list_core_devices_paginator: ListCoreDevicesPaginator = client.get_paginator("list_core_devices")
    list_deployments_paginator: ListDeploymentsPaginator = client.get_paginator("list_deployments")
    list_effective_deployments_paginator: ListEffectiveDeploymentsPaginator = client.get_paginator("list_effective_deployments")
    list_installed_components_paginator: ListInstalledComponentsPaginator = client.get_paginator("list_installed_components")
    ```
"""
import sys
from typing import Iterator

from botocore.paginate import Paginator as Boto3Paginator

from mypy_boto3_greengrassv2.type_defs import (
    ListComponentsResponseTypeDef,
    ListComponentVersionsResponseTypeDef,
    ListCoreDevicesResponseTypeDef,
    ListDeploymentsResponseTypeDef,
    ListEffectiveDeploymentsResponseTypeDef,
    ListInstalledComponentsResponseTypeDef,
    PaginatorConfigTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = (
    "ListComponentVersionsPaginator",
    "ListComponentsPaginator",
    "ListCoreDevicesPaginator",
    "ListDeploymentsPaginator",
    "ListEffectiveDeploymentsPaginator",
    "ListInstalledComponentsPaginator",
)

class ListComponentVersionsPaginator(Boto3Paginator):
    """
    [Paginator.ListComponentVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListComponentVersions)
    """

    def paginate(
        self, arn: str, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListComponentVersionsResponseTypeDef]:
        """
        [ListComponentVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListComponentVersions.paginate)
        """

class ListComponentsPaginator(Boto3Paginator):
    """
    [Paginator.ListComponents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListComponents)
    """

    def paginate(
        self,
        scope: Literal["PRIVATE", "PUBLIC"] = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[ListComponentsResponseTypeDef]:
        """
        [ListComponents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListComponents.paginate)
        """

class ListCoreDevicesPaginator(Boto3Paginator):
    """
    [Paginator.ListCoreDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListCoreDevices)
    """

    def paginate(
        self,
        thingGroupArn: str = None,
        status: Literal["HEALTHY", "UNHEALTHY"] = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[ListCoreDevicesResponseTypeDef]:
        """
        [ListCoreDevices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListCoreDevices.paginate)
        """

class ListDeploymentsPaginator(Boto3Paginator):
    """
    [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListDeployments)
    """

    def paginate(
        self,
        targetArn: str = None,
        historyFilter: Literal["ALL", "LATEST_ONLY"] = None,
        PaginationConfig: PaginatorConfigTypeDef = None,
    ) -> Iterator[ListDeploymentsResponseTypeDef]:
        """
        [ListDeployments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListDeployments.paginate)
        """

class ListEffectiveDeploymentsPaginator(Boto3Paginator):
    """
    [Paginator.ListEffectiveDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListEffectiveDeployments)
    """

    def paginate(
        self, coreDeviceThingName: str, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListEffectiveDeploymentsResponseTypeDef]:
        """
        [ListEffectiveDeployments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListEffectiveDeployments.paginate)
        """

class ListInstalledComponentsPaginator(Boto3Paginator):
    """
    [Paginator.ListInstalledComponents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListInstalledComponents)
    """

    def paginate(
        self, coreDeviceThingName: str, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListInstalledComponentsResponseTypeDef]:
        """
        [ListInstalledComponents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListInstalledComponents.paginate)
        """



"""
Main interface for greengrassv2 service client

Usage::

    ```python
    import boto3
    from mypy_boto3_greengrassv2 import GreengrassV2Client

    client: GreengrassV2Client = boto3.client("greengrassv2")
    ```
"""
import sys
from typing import IO, Any, Dict, List, Type, Union, overload

from botocore.client import ClientMeta

from mypy_boto3_greengrassv2.paginator import (
    ListComponentsPaginator,
    ListComponentVersionsPaginator,
    ListCoreDevicesPaginator,
    ListDeploymentsPaginator,
    ListEffectiveDeploymentsPaginator,
    ListInstalledComponentsPaginator,
)
from mypy_boto3_greengrassv2.type_defs import (
    CancelDeploymentResponseTypeDef,
    ComponentCandidateTypeDef,
    ComponentDeploymentSpecificationTypeDef,
    ComponentPlatformTypeDef,
    CreateComponentVersionResponseTypeDef,
    CreateDeploymentResponseTypeDef,
    DeploymentIoTJobConfigurationTypeDef,
    DeploymentPoliciesTypeDef,
    DescribeComponentResponseTypeDef,
    GetComponentResponseTypeDef,
    GetComponentVersionArtifactResponseTypeDef,
    GetCoreDeviceResponseTypeDef,
    GetDeploymentResponseTypeDef,
    LambdaFunctionRecipeSourceTypeDef,
    ListComponentsResponseTypeDef,
    ListComponentVersionsResponseTypeDef,
    ListCoreDevicesResponseTypeDef,
    ListDeploymentsResponseTypeDef,
    ListEffectiveDeploymentsResponseTypeDef,
    ListInstalledComponentsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ResolveComponentCandidatesResponseTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = ("GreengrassV2Client",)

class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str
    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str

class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class GreengrassV2Client:
    """
    [GreengrassV2.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client)
    """

    meta: ClientMeta
    exceptions: Exceptions
    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.can_paginate)
        """
    def cancel_deployment(self, deploymentId: str) -> CancelDeploymentResponseTypeDef:
        """
        [Client.cancel_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.cancel_deployment)
        """
    def create_component_version(
        self,
        inlineRecipe: Union[bytes, IO[bytes]] = None,
        lambdaFunction: LambdaFunctionRecipeSourceTypeDef = None,
        tags: Dict[str, str] = None,
    ) -> CreateComponentVersionResponseTypeDef:
        """
        [Client.create_component_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.create_component_version)
        """
    def create_deployment(
        self,
        targetArn: str,
        deploymentName: str = None,
        components: Dict[str, "ComponentDeploymentSpecificationTypeDef"] = None,
        iotJobConfiguration: "DeploymentIoTJobConfigurationTypeDef" = None,
        deploymentPolicies: "DeploymentPoliciesTypeDef" = None,
        tags: Dict[str, str] = None,
    ) -> CreateDeploymentResponseTypeDef:
        """
        [Client.create_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.create_deployment)
        """
    def delete_component(self, arn: str) -> None:
        """
        [Client.delete_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.delete_component)
        """
    def delete_core_device(self, coreDeviceThingName: str) -> None:
        """
        [Client.delete_core_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.delete_core_device)
        """
    def describe_component(self, arn: str) -> DescribeComponentResponseTypeDef:
        """
        [Client.describe_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.describe_component)
        """
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.generate_presigned_url)
        """
    def get_component(
        self, arn: str, recipeOutputFormat: Literal["JSON", "YAML"] = None
    ) -> GetComponentResponseTypeDef:
        """
        [Client.get_component documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.get_component)
        """
    def get_component_version_artifact(
        self, arn: str, artifactName: str
    ) -> GetComponentVersionArtifactResponseTypeDef:
        """
        [Client.get_component_version_artifact documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.get_component_version_artifact)
        """
    def get_core_device(self, coreDeviceThingName: str) -> GetCoreDeviceResponseTypeDef:
        """
        [Client.get_core_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.get_core_device)
        """
    def get_deployment(self, deploymentId: str) -> GetDeploymentResponseTypeDef:
        """
        [Client.get_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.get_deployment)
        """
    def list_component_versions(
        self, arn: str, maxResults: int = None, nextToken: str = None
    ) -> ListComponentVersionsResponseTypeDef:
        """
        [Client.list_component_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.list_component_versions)
        """
    def list_components(
        self,
        scope: Literal["PRIVATE", "PUBLIC"] = None,
        maxResults: int = None,
        nextToken: str = None,
    ) -> ListComponentsResponseTypeDef:
        """
        [Client.list_components documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.list_components)
        """
    def list_core_devices(
        self,
        thingGroupArn: str = None,
        status: Literal["HEALTHY", "UNHEALTHY"] = None,
        maxResults: int = None,
        nextToken: str = None,
    ) -> ListCoreDevicesResponseTypeDef:
        """
        [Client.list_core_devices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.list_core_devices)
        """
    def list_deployments(
        self,
        targetArn: str = None,
        historyFilter: Literal["ALL", "LATEST_ONLY"] = None,
        maxResults: int = None,
        nextToken: str = None,
    ) -> ListDeploymentsResponseTypeDef:
        """
        [Client.list_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.list_deployments)
        """
    def list_effective_deployments(
        self, coreDeviceThingName: str, maxResults: int = None, nextToken: str = None
    ) -> ListEffectiveDeploymentsResponseTypeDef:
        """
        [Client.list_effective_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.list_effective_deployments)
        """
    def list_installed_components(
        self, coreDeviceThingName: str, maxResults: int = None, nextToken: str = None
    ) -> ListInstalledComponentsResponseTypeDef:
        """
        [Client.list_installed_components documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.list_installed_components)
        """
    def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.list_tags_for_resource)
        """
    def resolve_component_candidates(
        self,
        platform: "ComponentPlatformTypeDef",
        componentCandidates: List[ComponentCandidateTypeDef],
    ) -> ResolveComponentCandidatesResponseTypeDef:
        """
        [Client.resolve_component_candidates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.resolve_component_candidates)
        """
    def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.tag_resource)
        """
    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Client.untag_resource)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_component_versions"]
    ) -> ListComponentVersionsPaginator:
        """
        [Paginator.ListComponentVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListComponentVersions)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_components"]) -> ListComponentsPaginator:
        """
        [Paginator.ListComponents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListComponents)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_core_devices"]
    ) -> ListCoreDevicesPaginator:
        """
        [Paginator.ListCoreDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListCoreDevices)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_deployments"]
    ) -> ListDeploymentsPaginator:
        """
        [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListDeployments)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_effective_deployments"]
    ) -> ListEffectiveDeploymentsPaginator:
        """
        [Paginator.ListEffectiveDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListEffectiveDeployments)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_installed_components"]
    ) -> ListInstalledComponentsPaginator:
        """
        [Paginator.ListInstalledComponents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.45/reference/services/greengrassv2.html#GreengrassV2.Paginator.ListInstalledComponents)
        """
